![CI](https://github.com/intellineers/django-bridger/workflows/CI/badge.svg)
[![codecov](https://codecov.io/gh/intellineers/django-bridger/branch/master/graph/badge.svg)](https://codecov.io/gh/intellineers/django-bridger)
[![Documentation Status](https://readthedocs.org/projects/django-bridger/badge/?version=latest)](https://django-bridger.readthedocs.io/en/latest/?badge=latest)
[![PyPI](https://img.shields.io/pypi/v/django-bridger?color=%23386fa4)](https://pypi.org/project/django-bridger/)


# Django Bridger
A django app, that bridges the gap between the backend and frontend to enable automatic creation of frontend apps.

### This is a Pre-Release Version and should not be used in production!!!
